if (FALSE) {
# Get the complete checklist of Italy
italic_checklist()
# Get the complete checklist of Italy and bordering countries
italic_checklist(include_bordering_countries=TRUE)
# Get the checklist of the species of genus Lecanora
italic_checklist(genus ="Lecanora")
}
Run the code above in your browser using DataLab