Learn R Programming

ritalic (version 0.11.0)

italic_description: Get descriptions of lichen taxa

Description

Retrieves morphological descriptions and additional taxonomic or ecological notes about lichen taxa present in the Checklist of the Lichens of Italy. Only accepts names that exist in the database of ITALIC.

Usage

italic_description(sp_names)

Value

A data frame with columns:

scientific_name

The scientific name provided as input

description

Morphological description

notes

Additional taxonomic or ecological information

Arguments

sp_names

Character vector of accepted names

Examples

Run this code
if (FALSE) {
italic_description("Cetraria islandica (L.) Ach. subsp. islandica")
}


Run the code above in your browser using DataLab