Learn R Programming

ritalic (version 0.11.0)

italic_distribution_map: Create distribution map of a lichen taxon

Description

Creates a distribution map for a given lichen species based on its commonness/rarity status across Italian ecoregions and presence/absence across administrative regions. The map visually represents the data obtained from italic_ecoregions_distribution() and italic_regions_distribution().

Usage

italic_distribution_map(sp_name, plot_map = TRUE)

Value

if plot_map = TRUE (default) a ggplot object representing the distribution map where Italian areas are colored according to the species' commonness/rarity. If plot_map = FALSE the sf object used to create the plot

Arguments

sp_name

Character string representing the accepted scientific name of a lichen species.

plot_map

If TRUE (default) the function returns a ggplot graph, if FALSE returns a sf object

Details

The function internally utilizes italic_ecoregions_distribution() and italic_regions_distribution() to retrieve the commonness/rarity status across Italian ecoregions and presence/absence across administrative regions data for the provided species. It then joins this data with a geospatial dataset of Italian regions and ecoregions (included in the package) to generate the map.

Commonness/rarity categories are visualized with a color scale, where each color corresponds to a different level of commonness/rarity ("extremely common", "very common", "common", "rather common", "rather rare", "rare", "very rare", "extremely rare", "absent").

References

For more information about Italian ecoregions see ITALIC ecoregions distribution https://italic.units.it/?procedure=base&t=59&c=60#commonness and the scientific publication describing the ecoregions used in ITALIC https://www.mdpi.com/1424-2818/12/8/294

Examples

Run this code
if (FALSE) {
italic_distribution_map("Flavoparmelia caperata (L.) Hale")
italic_distribution_map("Anisomeridium biforme (Schaer.) R.C. Harris")
}

Run the code above in your browser using DataLab