Learn R Programming

ritalic (version 0.11.0)

italic_identification_key: Generate interactive identification keys for lichen taxa

Description

Creates a URL link to a custom interactive dichotomous key for identifying the specified lichen taxa using the KeyMaker system of ITALIC. Only accepts names that exist in the database of ITALIC.

Usage

italic_identification_key(sp_names)

Value

Character string containing the URL to a web-based interactive identification key. The key is uniquely generated for the input taxa and allows step-by-step identification through dichotomous choices.

Arguments

sp_names

Character vector of accepted names

References

ITALIC - The KeyMaker https://italic.units.it/key-maker/

Examples

Run this code
if (FALSE) {
# Generate key for two species
italic_identification_key(c("Cetraria ericetorum Opiz","Xanthoria parietina (L.) Th. Fr."))
}

Run the code above in your browser using DataLab