Learn R Programming

ritalic (version 0.11.0)

italic_name_usage: Get details of species names

Description

Retrieves information for a scientific name used in ITALIC, including name id, taxonomic status, Index Fungorum id and related taxon id.

Usage

italic_name_usage(sp_names)

Value

A data frame with columns:

input_name

The scientific name provided as input

scientific_name_id

Unique identifier of ITALIC for the scientific name

index_fungorum_id

Corresponding Index Fungorum identifier

scientific_name_full

Complete scientific name including authority

scientific_name

Scientific name without authority

authorship

Author of the name

notes

Additional notes about the taxon, if any

rank

Taxonomic rank of the name

status

Taxonomic status ('accepted', 'synonym' or 'basionym')

related_accepted_name_id

ID of the currently accepted name related to the input name in ITALIC

related_accepted_name

Full accepted name

related_taxon_id

ID of the related taxon in ITALIC

Arguments

sp_names

Character vector of matched names or accepted names

Examples

Run this code
if (FALSE) {
italic_name_usage(c("Cetraria islandica (L.) Ach. subsp. islandica", "Secoliga annexa Arnold"))
}

Run the code above in your browser using DataLab