Learn R Programming

ritalic (version 0.11.0)

italic_taxonomy: Get taxonomic classification of lichen taxa

Description

Retrieves the complete taxonomic classification of lichen taxa from the ITALIC database. Only accepts names that exist in the database of ITALIC.

Usage

italic_taxonomy(sp_names)

Value

A data frame with:

scientific_name

The scientific name provided as input

phylum

Phylum

class

Class

order

Order

family

Family

genus

Genus

Arguments

sp_names

Character vector of accepted names

Examples

Run this code
if (FALSE) {
italic_taxonomy("Cetraria islandica (L.) Ach. subsp. islandica")
}

Run the code above in your browser using DataLab