Learn R Programming

ritalic (version 0.11.0)

italic_traits_pa: Get a presence-absence matrix of lichen traits

Description

This function returns morphological traits of the lichen species passed as input. Only accepts names that exist in the database of ITALIC.

Usage

italic_traits_pa(sp_names)

Value

A dataframe containing a series of traits for the lichen species passed as input.

Arguments

sp_names

A vector containing scientific names of lichens.

Examples

Run this code
if (FALSE) {
italic_traits_pa("Cetraria ericetorum Opiz")
}

Run the code above in your browser using DataLab