The function internally utilizes italic_ecoregions_distribution() and italic_regions_distribution() to retrieve the commonness/rarity
status across Italian ecoregions and presence/absence across administrative regions data for the provided species.
It then joins this data with a geospatial dataset of Italian regions and ecoregions (included in the package) to generate the map.
Commonness/rarity categories are visualized with a color scale, where each color
corresponds to a different level of commonness/rarity ("extremely common", "very common",
"common", "rather common", "rather rare", "rare", "very rare", "extremely rare", "absent").