This function returns a dataframe containing taxonomy, ecology_traits, regions_distribution, ecoregions_distribution of the lichen species passed as input. For more info about these parameters see https://italic.units.it/?procedure=base&t=59&c=60#otherdata
Only accepts names that exist in the database of ITALIC.
Usage
italic_taxon_data(sp_names)
Value
A dataframe containing the taxonomy, ecology distribution and rarity of the lichen species passed as input.
Arguments
sp_names
A vector containing the scientific names of the lichen species.