powered by
Retrieves the complete taxonomic classification of lichen taxa from the ITALIC database. Only accepts names that exist in the database of ITALIC.
italic_taxonomy(sp_names)
A data frame with:
The scientific name provided as input
Phylum
Class
Order
Family
Genus
Character vector of accepted names
if (FALSE) { italic_taxonomy("Cetraria islandica (L.) Ach. subsp. islandica") }
Run the code above in your browser using DataLab