powered by
This function returns morphological traits of the lichen species passed as input. Only accepts names that exist in the database of ITALIC.
italic_traits_pa(sp_names)
A dataframe containing a series of traits for the lichen species passed as input.
A vector containing scientific names of lichens.
if (FALSE) { italic_traits_pa("Cetraria ericetorum Opiz") }
Run the code above in your browser using DataLab